@@ -110,6 +110,14 @@ if HAS_CRYPTOBOX:
             if not (self.originator_box or self.responder_box):
                 raise Exception("insufficient keys provided for at least originator or responder role")
 
+    @public
+    class SymKey(object):
+        """
+        Holds a symmetric key for an URI.
+        """
+        def __init__(self, raw=None):
+            pass
+
     @public
     class KeyRing(object):
         """
@@ -139,7 +147,7 @@ if HAS_CRYPTOBOX:
             key = PrivateKey.generate()
             priv_key = key.encode(encoder=Base64Encoder)
             pub_key = key.public_key.encode(encoder=Base64Encoder)
-            return (u'{}'.format(priv_key), u''.format(pub_key))
+            return (u'{}'.format(priv_key), u'{}'.format(pub_key))
 
         @public
         def set_key(self, uri, key):
@@ -159,6 +167,14 @@ if HAS_CRYPTOBOX:
                 else:
                     self._uri_to_key[uri] = key
 
+        @public
+        def rotate_key(self, uri):
+            assert(type(uri) == six.text_type)
+            if uri in self._uri_to_key:
+                self._uri_to_key[uri].rotate()
+            else:
+                self._uri_to_key[uri].rotate()
+
         def _get_box(self, is_originating, uri, match_exact=False):
             try:
                 if match_exact:
